#!/bin/sh

# ****************************************************************************
# IBM Confidential
# OCO Source Materials
# (c) Copyright IBM Corp. 2011
#
# The source code for this program is not published or otherwise divested of 
# its trade secrets, irrespective of what has been deposited with the U.S. 
# Copyright Office.
# ****************************************************************************


# This script will setup the historical collection required for the ITM for
# Virtual Environments 7.1 release.  Historical Configuration is setup for 
# each attribute group that is used for the Tivoli Common Reporting (TCR) 
# VMware Reports and for the Capacity Planning component.  
# 
# In the sections below, each attribute group is documented as being used for
# TCR Reporting, Capacity Planning, both, or is simply available in the Cognos
# data model so that you can create your own custom reports.  Someo of the 
# sections are commented out because Tivoli does not recommend collecting that
# historical data even though it is available in the data model.
#
# This section describes the attributes used in the script.  The values 
# provided in the script are Tivoli's recommendations, but you may make changes
# using the guidelines below.
# -c|--collectioninterval Specifies the collection interval. The acceptable 
#     inputs are 1m(inute), 5m, 15m, 30m, 1h(our), or 1d(ay). The default value 
#     is 15m(inutes).
# -l|--collectionlocation Specifies where the data collection is stored. 
#     The acceptable inputs are TEMA or TEMS. The default value is TEMA.
# -i|--warehouseinterval Specifies the warehouse interval. The acceptable inputs
#     are 15m(inutes), 30m, 1h(our), 12h, 1d(ay), or off. The default value is 
#     1d(ay).
# -d|--summarizationdetails Specifies the summarization details. If this option 
#     is not specified, summarization will be disabled. This option can be 
#     given as DH where Y=Yearly,Q=Quarterly,M=Monthly,W=Weekly,D=Daily, and 
#     H=Hourly.
# -p|--pruningdetails Specifies the pruning details. If this option is not 
#     specified, Pruning will be disabled. This option can be given as Y=1y,
#     Q=1y,M=2m,W=2m,D=1d,H=2d,R=2d where Y=Yearly,Q=Quarterly,M=Monthly,
#     W=Weekly,D=Daily,H=Hourly, and R=Detailed data.

# NOTE:  There are several tables used for Capacity Planning.   It is important
# that the capacity planning tables be configured with the same summarization 
# and pruning intervals.   This does not apply to the tables being used for
# Tivoli Common Reporting.  The tables are:
# KVM DATASTORES
# KVM SERVER
# KVM SERVER CPU
# KVM SERVER DATASTORE
# KVM SERVER DISK
# KVM SERVER HBA
# KVM SERVER MEMORY
# KVM SERVER NETWORK
# KVM VIRTUAL MACHINES
# KVM VM CPU
# KVM VM DATASTORE UTILIZATION
# KVM VM DISK
# KVM VM MEMORY
# KVM VM NETWORK
# KVM VM PARTITION
# By default, these tables are being setup with 120 days of Daily summarization
# data and 30 days of Hourly summarization.



# First, check to make sure that the user logs into the TEPS correctly.
if [ $# -lt 3 ]
then
   echo "The script requires 3 parameters and has 1 optional parameter"
   echo "The syntax is:"
   echo "vmware_hist_config.sh <TEPS Hostname> <username> <password> [ITM PATH]"
   exit 0
else
   if [ -z $4 ]
   then
      echo ""
      echo "Using Default CANDLEHOME of /opt/IBM/ITM.  If you are using a different"
      echo "CANDLEHOME directory, please run the program again and specify the"
      echo " CANDLEHOME directory.  The command syntax is:"
      echo "vmware_hist_config.sh <TEPS Hostname> <username> <password> [ITM PATH]"
      echo " "
      export CANDLEHOME=/opt/IBM/ITM
   else
      echo "CANDLEHOME is set to " $4
      export CANDLEHOME=$4
   fi
fi

# Test whether login is successful and set timeout to 4 hours
if [ -z `$CANDLEHOME/bin/tacmd tepslogin -s $1 -u $2 -p $3 -t 240 | grep KUIC00007I | cut -f 1 -d :` ]
then
   echo "Login Failed"
   exit 0
fi

echo "Login succeeded.  Beginning historical configuration.  The results will"
echo "be logged to histconfig.log"

exec > ./histconfig.log
exec 2>&1


CURDIR=`pwd`

#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
#./vmware_check_hist_config.sh "KVM DISTRIBUTED VIRTUAL PORTGROUPS"
retStatus=$?

#if [ $retStatus -eq 1 ];
#then
# 	Configure Summarization
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM DISTRIBUTED VIRTUAL PORTGROUPS" -m -d D -p D=30d,R=3d
#fi

#if [ $retStatus -eq 2 ];
#then
#	Configure Historical Collection
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_DISTRIBUTED_VIRTUAL_PORTGROUPS" -t "vm" -o "KVM DISTRIBUTED VIRTUAL PORTGROUPS" -i 1h -l TEMA -c 15m -e "historical coll for Distributed Virtual Portgroups"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_DISTRIBUTED_VIRTUAL_PORTGROUPS" -m '*VMWARE_VI_AGENT'
#fi

#if [ $retStatus -eq 3 ];
#then
# 	Configure both S&P and Historical Collection
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM DISTRIBUTED VIRTUAL PORTGROUPS" -m -d D -p D=30d,R=3d
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_DISTRIBUTED_VIRTUAL_PORTGROUPS" -t "vm" -o "KVM DISTRIBUTED VIRTUAL PORTGROUPS" -i 1h -l TEMA -c 15m -e "historical coll for Distributed Virtual Portgroups"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_DISTRIBUTED_VIRTUAL_PORTGROUPS" -m '*VMWARE_VI_AGENT'
#fi



#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
#./vmware_check_hist_config.sh "KVM DISTRIBUTED VIRTUAL SWITCHES"
retStatus=$?

#if [ $retStatus -eq 1 ];
#then
# 	Configure Summarization
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM DISTRIBUTED VIRTUAL SWITCHES" -m -d D -p D=30d,R=3d
#fi

#if [ $retStatus -eq 2 ];
#then
#	Configure Historical Collection
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_DISTRIBUTED_VIRTUAL_SWITCHES" -t "vm" -o "KVM DISTRIBUTED VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for Distributed Virtual Switches"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_DISTRIBUTED_VIRTUAL_SWITCHES" -m '*VMWARE_VI_AGENT'
#fi

#if [ $retStatus -eq 3 ];
#then
# 	Configure both S&P and Historical Collection
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM DISTRIBUTED VIRTUAL SWITCHES" -m -d D -p D=30d,R=3d
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_DISTRIBUTED_VIRTUAL_SWITCHES" -t "vm" -o "KVM DISTRIBUTED VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for Distributed Virtual Switches"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_DISTRIBUTED_VIRTUAL_SWITCHES" -m '*VMWARE_VI_AGENT'
#fi



#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM CLUSTERED DATASTORES"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM CLUSTERED DATASTORES"
        $CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED DATASTORES" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM CLUSTERED DATASTORES"
        $CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_Clustered_Datastores" -t "vm" -o "KVM CLUSTERED DATASTORES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster Datastore metrics"
        $CANDLEHOME/bin/tacmd histstartCollection -a "KVM_Clustered_Datastores" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "configuring both S&P and Historical collection for KVM CLUSTERD DATASTORES"
        $CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED DATASTORES" -m -d DH -p D=60d,H=14d,R=3d
        $CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_Clustered_Datastores" -t "vm" -o "KVM CLUSTERED DATASTORES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster Datastore metrics"
        $CANDLEHOME/bin/tacmd histstartCollection -a "KVM_Clustered_Datastores" -m '*VMWARE_VI_AGENT'
fi


#----------------------------------------------------------------------------
# This attribute group is used for the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM CLUSTERED RESOURCE POOLS"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM CLUSTERED RESOURCE POOLS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED RESOURCE POOLS" -m -d D -p D=60d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring historical collection for KVM CLUSTERED RESOURCE POOLS"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_Clustered_Resource_Pools" -t "vm" -o "KVM CLUSTERED RESOURCE POOLS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster Resource metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_Clustered_Resource_Pools" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
echo "configuring both S&P and Historical collection for KVM CLUSTED RESOURCE POOLS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED RESOURCE POOLS" -m -d D -p D=60d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_Clustered_Resource_Pools" -t "vm" -o "KVM CLUSTERED RESOURCE POOLS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster Resource metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_Clustered_Resource_Pools" -m '*VMWARE_VI_AGENT'
fi

#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM CLUSTERED SERVERS"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM CLUSTERS SERVERS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED SERVERS" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM CLUSTERS SERVERS"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_Clustered_Servers" -t "vm" -o "KVM CLUSTERED SERVERS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster Server metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_Clustered_Servers" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM CLUSTERS SERVERS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED SERVERS" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_Clustered_Servers" -t "vm" -o "KVM CLUSTERED SERVERS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster Server metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_Clustered_Servers" -m '*VMWARE_VI_AGENT'
fi


#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM CLUSTERED VIRTUAL MACHINES"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM CLUSTERED VIRTUAL MACHINES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED VIRTUAL MACHINES" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM CLUSTERED VIRTUAL MACHINES"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_CLUSTERED_VIRTUAL_MACHINES" -t "vm" -o "KVM CLUSTERED VIRTUAL MACHINES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster VM  metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_CLUSTERED_VIRTUAL_MACHINES" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM CLUSTERED VIRTUAL MACHINES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERED VIRTUAL MACHINES" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_CLUSTERED_VIRTUAL_MACHINES" -t "vm" -o "KVM CLUSTERED VIRTUAL MACHINES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster VM  metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_CLUSTERED_VIRTUAL_MACHINES" -m '*VMWARE_VI_AGENT'
fi


#----------------------------------------------------------------------------
# This attribute group is used for the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM CLUSTERS"
retStatus=$?
if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM CLUSTERS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERS" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM CLUSTERS"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_CLUSTERS" -t "vm" -o "KVM CLUSTERS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_CLUSTERS" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM CLUSTERS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM CLUSTERS" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_CLUSTERS" -t "vm" -o "KVM CLUSTERS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Cluster metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_CLUSTERS" -m '*VMWARE_VI_AGENT'
fi



#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM RESOURCE POOL CPU"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM RESOURCE POOL CPU"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM RESOURCE POOL CPU" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM RESOURCE POOL CPU"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_RESOURCE_POOL_CPU" -t "vm" -o "KVM RESOURCE POOL CPU" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Resource Pool CPU metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_RESOURCE_POOL_CPU" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM RESOURCE POOL CPU"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM RESOURCE POOL CPU" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_RESOURCE_POOL_CPU" -t "vm" -o "KVM RESOURCE POOL CPU" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Resource Pool CPU metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_RESOURCE_POOL_CPU" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM RESOURCE POOL GENERAL"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM RESOURCE POOL GENERAL"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM RESOURCE POOL GENERAL" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM RESOURCE POOL GENERAL"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_RESOURCE_POOL_GENERAL" -t "vm" -o "KVM RESOURCE POOL GENERAL" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Resource Pool metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_RESOURCE_POOL_GENERAL" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM RESOURCE POOL GENERAL"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM RESOURCE POOL GENERAL" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_RESOURCE_POOL_GENERAL" -t "vm" -o "KVM RESOURCE POOL GENERAL" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Resource Pool metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_RESOURCE_POOL_GENERAL" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM RESOURCE POOL MEMORY"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM RESOURCE POOL MEMORY"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM RESOURCE POOL MEMORY" -m -d D -p D=60d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM RESOURCE POOL MEMORY"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_RESOURCE_POOL_MEMORY" -t "vm" -o "KVM RESOURCE POOL MEMORY" -i 1h -l TEMA -c 1h -e "historical coll for VMware VI Resource Memory metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_RESOURCE_POOL_MEMORY" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM RESOURCE POOL MEMORY"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM RESOURCE POOL MEMORY" -m -d D -p D=60d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_RESOURCE_POOL_MEMORY" -t "vm" -o "KVM RESOURCE POOL MEMORY" -i 1h -l TEMA -c 1h -e "historical coll for VMware VI Resource Memory metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_RESOURCE_POOL_MEMORY" -m '*VMWARE_VI'
fi

#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM NETWORKED SERVERS"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM NETWORKED SERVERS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKED SERVERS" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM NETWORKED SERVERS"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKED_SERVERS" -t "vm" -o "KVM NETWORKED SERVERS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Networked servers metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKED_SERVERS" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM NETWORKED SERVERS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKED SERVERS" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKED_SERVERS" -t "vm" -o "KVM NETWORKED SERVERS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Networked servers metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKED_SERVERS" -m '*VMWARE_VI_AGENT'
fi



#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
#./vmware_check_hist_config.sh "KVM NETWORKED VIRTUAL MACHINES"
retStatus=$?

#if [ $retStatus -eq 1 ];
#then
# 	Configure Summarization
#	echo "Configuring Summarization & Pruning for KVM NETWORKED VIRTUAL MACHINES"
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKED VIRTUAL MACHINES" -m -d D -p D=60d,R=3d
#fi

#if [ $retStatus -eq 2 ];
#then
#	Configure Historical Collection
#	echo "Configuring Historical Collection for KVM NETWORKED VIRTUAL MACHINES"
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKED_VIRTUAL_MACHINES" -t "vm" -o "KVM NETWORKED VIRTUAL MACHINES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Networked Virtual Machines metrics"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKED_VIRTUAL_MACHINES" -m '*VMWARE_VI_AGENT'
#fi

#if [ $retStatus -eq 3 ];
#then
# 	Configure both S&P and Historical Collection
#	echo "Configuring both Historical Collection and S&P for KVM NETWORKED VIRTUAL MACHINES"
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKED VIRTUAL MACHINES" -m -d D -p D=60d,R=3d
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKED_VIRTUAL_MACHINES" -t "vm" -o "KVM NETWORKED VIRTUAL MACHINES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Networked Virtual Machines metrics"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKED_VIRTUAL_MACHINES" -m '*VMWARE_VI_AGENT'
#fi


#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM NETWORKED VIRTUAL SWITCHES"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM NETWORKED VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKED VIRTUAL SWITCHES" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM NETWORKED VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKED_VIRTUAL_SWITCHES" -t "vm" -o "KVM NETWORKED VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Networked Virtual Switches metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKED_VIRTUAL_SWITCHES" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM NETWORKED VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKED VIRTUAL SWITCHES" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKED_VIRTUAL_SWITCHES" -t "vm" -o "KVM NETWORKED VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Networked Virtual Switches metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKED_VIRTUAL_SWITCHES" -m '*VMWARE_VI_AGENT'
fi


#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM NETWORKS"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM NETWORKS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKS" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM NETWORKS"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKS" -t "vm" -o "KVM NETWORKS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Network metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKS" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring Historical Collection and S&P for KVM NETWORKS"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM NETWORKS" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_NETWORKS" -t "vm" -o "KVM NETWORKS" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Network metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_NETWORKS" -m '*VMWARE_VI_AGENT'
fi



#----------------------------------------------------------------------------
# This attribute group is used for the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER VIRTUAL SWITCHES"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER VIRTUAL SWITCHES" -m -d D -p D=60d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_VIRTUAL_SWITCHES" -t "vm" -o "KVM SERVER VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Virtual Switch metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_VIRTUAL_SWITCHES" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM SERVER VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER VIRTUAL SWITCHES" -m -d D -p D=60d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_VIRTUAL_SWITCHES" -t "vm" -o "KVM SERVER VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Virtual Switch metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_VIRTUAL_SWITCHES" -m '*VMWARE_VI'
fi

#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER" -t "vm" -o "KVM SERVER" -i 1h -l TEMA -c 5m -e "historical coll for VMware VI Server metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring Historical Collection and S&P for KVM SERVER"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER" -t "vm" -o "KVM SERVER" -i 1h -l TEMA -c 5m -e "historical coll for VMware VI Server metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER CPU"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER CPU"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER CPU" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER CPU"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_CPU" -t "vm" -o "KVM SERVER CPU" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server CPU metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_CPU" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM SERVER CPU"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER CPU" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_CPU" -t "vm" -o "KVM SERVER CPU" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server CPU metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_CPU" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM DATASTORES"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM DATASTORES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM DATASTORES" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM DATASTORES"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_DATASTORES" -t "vm" -o "KVM DATASTORES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Datastore metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_DATASTORES" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring Historical Collection and S&P for KVM DATASTORES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM DATASTORES" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_DATASTORES" -t "vm" -o "KVM DATASTORES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Datastore metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_DATASTORES" -m '*VMWARE_VI_AGENT'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER DATASTORE"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER DATASTORE"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER DATASTORE" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER DATASTORE"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_DATASTORE" -t "vm" -o "KVM SERVER DATASTORE" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Datastore metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_DATASTORE" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM SERVER DATASTORE"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER DATASTORE" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_DATASTORE" -t "vm" -o "KVM SERVER DATASTORE" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Datastore metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_DATASTORE" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER HBA"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER HBA"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER HBA" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER HBA"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_HBA" -t "vm" -o "KVM SERVER HBA" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server HBA metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_HBA" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection & S&P for KVM SERVER HBA"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER HBA" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_HBA" -t "vm" -o "KVM SERVER HBA" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server HBA metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_HBA" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER DISK"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER DISK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER DISK" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER DISK"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_DISK" -t "vm" -o "KVM SERVER DISK" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Disk metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_DISK" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM SERVER DISK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER DISK" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_DISK" -t "vm" -o "KVM SERVER DISK" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Disk metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_DISK" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
#./vmware_check_hist_config.sh "KVM SERVER SAN"
retStatus=$?

#if [ $retStatus -eq 1 ];
#then
# 	Configure Summarization
#	echo "Configuring Summarization & Pruning for KVM SERVER SAN"
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER SAN" -m -d DH -p D=60d,H=14d,R=3d
#fi

#if [ $retStatus -eq 2 ];
#then
#	Configure Historical Collection
#	echo "Configuring Historical Collection for KVM SERVER SAN"
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_SAN" -t "vm" -o "KVM SERVER SAN" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server SAN metrics"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_SAN" -m '*VMWARE_VI'
#fi

#if [ $retStatus -eq 3 ];
#then
# 	Configure both S&P and Historical Collection
#	echo "Configuring both Historical Collection and S&P for KVM SERVER SAN"
#	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER SAN" -m -d DH -p D=60d,H=14d,R=3d
#	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_SAN" -t "vm" -o "KVM SERVER SAN" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server SAN metrics"
#	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_SAN" -m '*VMWARE_VI'
#fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER MEMORY"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER MEMORY"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER MEMORY" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER MEMORY"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_MEMORY" -t "vm" -o "KVM SERVER MEMORY" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Memory metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_MEMORY" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM SERVER MEMORY"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER MEMORY" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_MEMORY" -t "vm" -o "KVM SERVER MEMORY" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Memory metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_MEMORY" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM SERVER NETWORK"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM SERVER NETWORK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER NETWORK" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM SERVER NETWORK"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_NETWORK" -t "vm" -o "KVM SERVER NETWORK" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Network metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_NETWORK" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM SERVER NETWORK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM SERVER NETWORK" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_SERVER_NETWORK" -t "vm" -o "KVM SERVER NETWORK" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Server Network metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_SERVER_NETWORK" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VIRTUAL MACHINES"
retStatus=$?
if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM VIRTUAL MACHINES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VIRTUAL MACHINES" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM VIRTUAL MACHINES"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VIRTUAL_MACHINES" -t "vm" -o "KVM VIRTUAL MACHINES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VIRTUAL_MACHINES" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM VIRTUAL MACHINES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VIRTUAL MACHINES" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VIRTUAL_MACHINES" -t "vm" -o "KVM VIRTUAL MACHINES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VIRTUAL_MACHINES" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This table is defined in the data model and can be used to create reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VIRTUAL SWITCHES"
retStatus=$?

if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VIRTUAL SWITCHES" -m -d DH -p D=60d,H=14d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VIRTUAL_SWITCHES" -t "vm" -o "KVM VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Virtual Switch metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VIRTUAL_SWITCHES" -m '*VMWARE_VI_AGENT'
fi
if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM VIRTUAL SWITCHES"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VIRTUAL SWITCHES" -m -d DH -p D=60d,H=14d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VIRTUAL_SWITCHES" -t "vm" -o "KVM VIRTUAL SWITCHES" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI Virtual Switch metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VIRTUAL_SWITCHES" -m '*VMWARE_VI_AGENT'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VM CPU"
retStatus=$?
if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM VM CPU"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM CPU" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM VM CPU"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_CPU" -t "vm" -o "KVM VM CPU" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM CPU metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_CPU" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM VM CPU"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM CPU" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_CPU" -t "vm" -o "KVM VM CPU" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM CPU metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_CPU" -m '*VMWARE_VI'
fi



#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VM DATASTORE UTILIZATION"
retStatus=$?
echo "return code = " $?
if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM VM DATASTORE UTILIZATION"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM DATASTORE UTILIZATION" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM VM DATASTORE UTILIZATION"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_DATASTORE_UTILIZATION" -t "vm" -o "KVM VM DATASTORE UTILIZATION" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM Disk metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_DATASTORE_UTILIZATION" -m '*VMWARE_VI_AGENT'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM VM DATASTORE UTILIZATION"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM DATASTORE UTILIZATION" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_DATASTORE_UTILIZATION" -t "vm" -o "KVM VM DATASTORE UTILIZATION" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM Disk metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_DATASTORE_UTILIZATION" -m '*VMWARE_VI_AGENT'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VM DISK"
retStatus=$?
echo "return code = " $?
if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configure Summarization & Pruning for KVM VM DISK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM DISK" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configure Historical Collection for KVM VM DISK"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_DISK" -t "vm" -o "KVM VM DISK" -i 1h -l TEMA -c 1h -e "historical coll for VMware VI VM Disk metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_DISK" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configure both Historical Collection and S&P for KVM VM DISK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM DISK" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_DISK" -t "vm" -o "KVM VM DISK" -i 1h -l TEMA -c 1h -e "historical coll for VMware VI VM Disk metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_DISK" -m '*VMWARE_VI'
fi



#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VM MEMORY"
retStatus=$?
if [ $? -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM VM MEMORY"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM MEMORY" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM VM MEMORY"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_MEMORY" -t "vm" -o "KVM VM MEMORY" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM Memory metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_MEMORY" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM VM MEMORY"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM MEMORY" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_MEMORY" -t "vm" -o "KVM VM MEMORY" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM Memory metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_MEMORY" -m '*VMWARE_VI'
fi



#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning and the VMware TCR reports

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VM NETWORK"
retStatus=$retStatus
echo "return code = " $?
if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM VM NETWORK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM NETWORK" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM VM NETWORK"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_NETWORK" -t "vm" -o "KVM VM NETWORK" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM Network metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_NETWORK" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM VM NETWORK"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM NETWORK" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_NETWORK" -t "vm" -o "KVM VM NETWORK" -i 1h -l TEMA -c 15m -e "historical coll for VMware VI VM Network metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_NETWORK" -m '*VMWARE_VI'
fi


#----------------------------------------------------------------------------
# This attribute group is used for Capacity Planning

# Check whether historical collection is already setup for this attribute group
./vmware_check_hist_config.sh "KVM VM PARTITION"
retStatus=$?
echo "return code = " $?
if [ $retStatus -eq 1 ];
then
# 	Configure Summarization
	echo "Configuring Summarization & Pruning for KVM VM PARTITION"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM PARTITION" -m -d DH -p D=120d,H=30d,R=3d
fi

if [ $retStatus -eq 2 ];
then
#	Configure Historical Collection
	echo "Configuring Historical Collection for KVM VM PARTITION"
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_PARTITION" -t "vm" -o "KVM VM PARTITION" -i 1h -l TEMA -c 1h -e "historical coll for VMware VI VM Partition metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_PARTITION" -m '*VMWARE_VI'
fi

if [ $retStatus -eq 3 ];
then
# 	Configure both S&P and Historical Collection
	echo "Configuring both Historical Collection and S&P for KVM VM PARTITION"
	$CANDLEHOME/bin/tacmd histconfiguregroups -t "vm" -o "KVM VM PARTITION" -m -d DH -p D=120d,H=30d,R=3d
	$CANDLEHOME/bin/tacmd histcreatecollection -a "KVM_VM_PARTITION" -t "vm" -o "KVM VM PARTITION" -i 1h -l TEMA -c 1h -e "historical coll for VMware VI VM Partition metrics"
	$CANDLEHOME/bin/tacmd histstartCollection -a "KVM_VM_PARTITION" -m '*VMWARE_VI'
fi


echo "Historical Configuration is now complete"
