SET NOCOUNT ON
USE itmuser
GO

CREATE SCHEMA IBM_TRAM; 
GO

PRINT N'Create table TIME_DIMENSION';
CREATE TABLE IBM_TRAM.TIME_DIMENSION (
	TIME_RANGE_START datetime NOT NULL,
	TIME_RANGE_END datetime NOT NULL,
	HOUR_KEY datetime NOT NULL,
	DAY_KEY datetime NOT NULL,
	WEEK_KEY datetime NOT NULL,
	MONTH_KEY datetime NOT NULL,
	QUARTER_KEY datetime NOT NULL,
	YEAR_KEY datetime NOT NULL,
	[CURRENT_DATE] datetime NOT NULL,
	CURRENT_MINUTE SMALLINT,	
	CURRENT_HOUR SMALLINT,
	CURRENT_DAY SMALLINT,
	CURRENT_WEEK SMALLINT,
	CURRENT_MONTH SMALLINT,
	CURRENT_QUARTER SMALLINT,
	CURRENT_YEAR SMALLINT,
	DAY_OF_WEEK SMALLINT,
	DAYS_IN_MONTH SMALLINT,
	DAY_OF_YEAR SMALLINT,
	WEEK_OF_MONTH SMALLINT,
	WEEK_OF_QUARTER SMALLINT,
	CANDLETIMESTAMP CHAR(16) NOT NULL,
	END_CANDLETIMESTAMP CHAR(16) NOT NULL,
		CONSTRAINT TIME_DIMENSION_PK PRIMARY KEY CLUSTERED (TIME_RANGE_START, TIME_RANGE_END)
	) ON [DEFAULT]
GO


CREATE UNIQUE NONCLUSTERED INDEX TIME_DIMENSION_MINUTE_KEY_IDX ON IBM_TRAM.TIME_DIMENSION (
	TIME_RANGE_START desc, TIME_RANGE_END asc
	) ON [DEFAULT]
GO

CREATE  NONCLUSTERED  INDEX IXCANDLE     ON IBM_TRAM.TIME_DIMENSION       
(CANDLETIMESTAMP, END_CANDLETIMESTAMP
	) ON [DEFAULT]
GO

CREATE NONCLUSTERED INDEX IXCURRYRMODAY     ON IBM_TRAM.TIME_DIMENSION      
 (CURRENT_YEAR, CURRENT_MONTH, CURRENT_DAY
  	) ON [DEFAULT]
GO

CREATE NONCLUSTERED INDEX IXCURRMODAY     ON IBM_TRAM.TIME_DIMENSION       
(CURRENT_MONTH, CURRENT_DAY	) ON [DEFAULT]
GO

CREATE NONCLUSTERED INDEX IXCURRMOWK     ON IBM_TRAM.TIME_DIMENSION       
(CURRENT_MONTH, CURRENT_WEEK	) ON [DEFAULT]
GO
	
CREATE NONCLUSTERED   INDEX IXCURRDAYHR     ON IBM_TRAM.TIME_DIMENSION      
 (CURRENT_DAY, CURRENT_HOUR	) ON [DEFAULT]
GO
 

PRINT N'Create table MONTH_LOOKUP';
CREATE TABLE IBM_TRAM.MONTH_LOOKUP	(
	MONTH_NUMBER SMALLINT,
	MONTH_EN VARCHAR(12),
	MONTH_FR VARCHAR(25),
	MONTH_PT_BR VARCHAR(25),
	MONTH_JA VARCHAR(25),
	MONTH_DE VARCHAR(25),
	MONTH_IT VARCHAR(25),
	MONTH_KO VARCHAR(25),
	MONTH_CS VARCHAR(25),
	MONTH_HU VARCHAR(25),
	MONTH_PL VARCHAR(25),
	MONTH_RU VARCHAR(75),
	MONTH_ZH_CN VARCHAR(25),
	MONTH_ZH_TW VARCHAR(25),
	MONTH_ES VARCHAR(25),
		CONSTRAINT MONTH_LOOKUP_PK PRIMARY KEY CLUSTERED (MONTH_NUMBER)
  ) ON [DEFAULT]
GO

PRINT N'Create table WEEKDAY_LOOKUP';
CREATE TABLE IBM_TRAM.WEEKDAY_LOOKUP	(
	WEEKDAY_NUMBER SMALLINT,
	WEEKDAY_EN VARCHAR(12),
	WEEKDAY_FR VARCHAR(25),
	WEEKDAY_PT_BR VARCHAR(25),
	WEEKDAY_JA VARCHAR(25),
	WEEKDAY_DE VARCHAR(25),
	WEEKDAY_IT VARCHAR(25),
	WEEKDAY_KO VARCHAR(25),
	WEEKDAY_CS VARCHAR(25),
	WEEKDAY_HU VARCHAR(25),
	WEEKDAY_PL VARCHAR(25),
	WEEKDAY_RU VARCHAR(75),
	WEEKDAY_ZH_CN VARCHAR(25),
	WEEKDAY_ZH_TW VARCHAR(25),
	WEEKDAY_ES VARCHAR(25),
		CONSTRAINT WEEKDAY_LOOKUP_PK PRIMARY KEY CLUSTERED (WEEKDAY_NUMBER)
  ) ON [DEFAULT]
GO


PRINT N'Create table TIMEZONE_DIMENSION';
CREATE TABLE IBM_TRAM.TIMEZONE_DIMENSION (
  TZOFF SMALLINT NOT NULL,
  DLS_START datetime,
  DLS_END datetime,
  DSLOFF SMALLINT,
  NAME_EN  VARCHAR(32) NOT NULL,
  ["DESC"] VARCHAR(128)
) ON [DEFAULT]
GO


PRINT N'Create table ComputerSystem';
CREATE TABLE IBM_TRAM.["ComputerSystem"]  (
  ["CSID"] INTEGER IDENTITY(1,1) NOT NULL,
  ["FQDN"]  VARCHAR (64) ,
  ["Manufacturer"] VARCHAR (64)  ,
  ["Model"] VARCHAR (64)  ,
  ["SerialNumber"] VARCHAR (64)  ,
  ["VMID"] VARCHAR(128),
  ["PrimaryMACAddress"] VARCHAR(64),
  ["IpAddress"] VARCHAR(32),
  ["Signature"] VARCHAR(128),
  ["ManagedSystemName"] VARCHAR(64),
  ["Group"] VARCHAR(64),
  ["TIME_RANGE_START"] DATETIME,
  ["TIME_RANGE_END"] DATETIME
CONSTRAINT COMPUTER_SYSTEM_PK PRIMARY KEY (["CSID"])
  ) ON [DEFAULT]
GO


PRINT 'TCR Shema created'
GO

PRINT 'TCR Shema: MONTH_LOOKUP - import data'
INSERT into IBM_TRAM.MONTH_LOOKUP(	MONTH_NUMBER,	MONTH_EN,	MONTH_FR,	MONTH_PT_BR,	MONTH_JA,	MONTH_DE,	MONTH_IT,	MONTH_KO,	MONTH_CS,	MONTH_HU,	MONTH_PL,	MONTH_RU,	MONTH_ZH_CN,	MONTH_ZH_TW,	MONTH_ES)
(select 1, 'January', 'Janvier', 'Janeiro', '1 月', 'Januar', 'Gennaio', '1월', 'Leden', 'Január', 'Styczeń', 'Январь', '一月','一月','Enero') 
union
(select 2, 'February', 'Février', 'Fevereiro', '2 月', 'Februar', 'Febbraio', '2월', 'Únor', 'Február', 'Luty', 'Февраль', '二月','二月','Febrero') 
union 
(select 3, 'March', 'Mars', 'Março', '3 月', 'März', 'Marzo', '3월', 'Březen', 'Március', 'Marzec', 'Март', '三月','三月','Marzo') 
union
(select 4, 'April', 'Avril', 'Abril', '4 月', 'April', 'Aprile', '4월', 'Duben', 'Április', 'Kwiecień', 'Апрель', '四月','四月','Abril') 
union
(select 5, 'May', 'Mai', 'Maio', '5 月', 'Mai', 'Maggio', '5월', 'Květen', 'Május', 'Maj', 'Май', '五月','五月','Mayo') 
union
(select 6, 'June', 'Juin', 'Junho', '6 月', 'Juni', 'Giugno', '6월', 'Červen', 'Június', 'Czerwiec', 'Июнь', '六月','六月','Junio') 
union 
(select 7, 'July', 'Juillet', 'Julho', '7 月', 'Juli', 'Luglio', '7월', 'Červenec', 'Július', 'Lipiec', 'Июль', '七月','七月','Julio') 
union
(select 8, 'August', 'Août', 'Agosto', '8 月', 'August', 'Agosto', '8월', 'Srpen', 'Augusztus', 'Sierpień', 'Август', '八月','八月','Agosto') 
union 
(select 9, 'September', 'Septembre', 'Setembro', '9 月', 'September', 'Settembre', '9월', 'Září', 'Szeptember', 'Wrzesień', 'Сентябрь', '九月','九月','Septiembre') 
union
(select 10, 'October', 'Octobre', 'Outubro', '10 月', 'Oktober', 'Ottobre', '10월', 'Říjen', 'Október', 'Październik', 'Октябрь', '十月','十月','Octubre') 
union 
(select 11, 'November', 'Novembre', 'Novembro', '11 月', 'November', 'Novembre', '11월', 'Listopad', 'November', 'Listopad', 'Ноябрь', '十一月','十一月','Noviembre') 
union 
(select 12, 'December', 'Décembre', 'Dezembro', '12 月', 'Dezember', 'Dicembre', '12월', 'Prosinec', 'December', 'Grudzień', 'Декабрь', '十二月','十二月','Diciembre');
GO 

PRINT 'TCR Shema: WEEKDAY_LOOKUP - import data'
INSERT into IBM_TRAM.WEEKDAY_LOOKUP(	WEEKDAY_NUMBER,	WEEKDAY_EN,	WEEKDAY_FR,	WEEKDAY_PT_BR,	WEEKDAY_JA,	WEEKDAY_DE,	WEEKDAY_IT,	WEEKDAY_KO,	WEEKDAY_CS,	WEEKDAY_HU,	WEEKDAY_PL,	WEEKDAY_RU,	WEEKDAY_ZH_CN,	WEEKDAY_ZH_TW,	WEEKDAY_ES  )
(select 1, 'Sunday', 'Dimanche', 'Domingo', '日曜日', 'Sonntag', 'Domenica', '일요일', 'Neděle', 'Vasárnap', 'Niedziela', 'Воскресенье', '星期日','星期日','Domingo' ) 
union 
(select 2, 'Monday', 'Lundi', 'Segunda-feira', '月曜日', 'Montag', 'Lunedì', '월요일', 'Pondělí', 'Hétfő', 'Poniedziałek', 'Понедельник', '星期一','星期一','Lunes') 
union 
(select 3, 'Tuesday', 'Mardi', 'Terça-feira', '火曜日', 'Dienstag', 'Martedì', '화요일', 'Úterý', 'Kedd', 'Wtorek', 'Вторник', '星期二','星期二','Martes') 
union
(select 4, 'Wednesday', 'Mercredi', 'Quarta-feira', '水曜日', 'Mittwoch', 'Mercoledì', '수요일', 'Středa', 'Szerda', 'Środa', 'Среда', '星期三','星期三','Miércoles') 
union
(select 5, 'Thursday', 'Jeudi', 'Quinta-feira', '木曜日', 'Donnerstag', 'Giovedì', '목요일', 'Čtvrtek', 'Csütörtök', 'Czwartek', 'Четверг', '星期四','星期四','Jueves') 
union 
(select 6, 'Friday', 'Vendredi', 'Sexta-feira', '金曜日', 'Freitag', 'Venerdì', '금요일', 'Pátek', 'Péntek', 'Piątek', 'Пятница', '星期五','星期五','Viernes') 
union
(select 7, 'Saturday', 'Samedi', 'Sábado', '土曜日', 'Samstag', 'Sabato', '토요일', 'Sobota', 'Szombat', 'Sobota', 'Суббота', '星期六','星期六','Sábado');
GO
